Glossary
--------

pseudocode:
   A way of designing programs by writing rough drafts in a combination
   of English and C++.

helper function:
   Often a small function that does not do anything enormously useful by
   itself, but which helps another, more useful, function.

top-down design:
   A method of program development that uses pseudocode to sketch
   solutions to large problems and design the interfaces of helper
   functions.

mergesort:
   An algorithm for sorting a collection of values. Mergesort is faster
   than the simple algorithm in the previous chapter, especially for
   large collections.

.. dragndrop:: glossary_13
    :feedback: Try again!
    :match_1: pseudocode|||A way of designing programs by writing rough drafts in a combination of English and C++.
    :match_2: helper function|||Often a small function that does not do anything enormously useful by itself, but which helps another, more useful, function.
    :match_3: top-down design|||A method of program development that uses pseudocode to sketch solutions to large problems and design the interfaces of helper functions.
    :match_4: mergesort|||An algorithm for sorting a collection of values. It is faster than the simple algorithm in the previous chapter, especially for large collections.

    Match the vocabulary word with its definition.
